==> pycsp3-1.0.4.tar.gz: pycsp3-1.0.4/pycsp3/problems/tests/g3_pattern.py <==
from pycsp3.problems.tests.tester import Tester, run

NAME = "g3_pattern"

diff = (Tester(NAME)
        .add("Dominoes", data="Dominoes_grid1.json")  # ok, unary constraints managed differently
        .add("Eternity", data="Eternity_07x05.json")  # ok, instantiation more compact
        .add("Eternity", data="Eternity_example.txt", prs_py="Eternity_Parser", prs_jv="Eternity_Parser")  # ok, instantiation more compact
        .add("Lightup", data="Lightup_example.txt", prs_py="Lightup_Parser", prs_jv="Lightup_Parser")  # ok, JvCSP more compact because reordering vars in count
        .add("ProgressiveParty", data="ProgressiveParty_example.txt", prs_py="ProgressiveParty_Parser", prs_jv="ProgressiveParty_Parser", special=True)
        # ok, group of alldiffExcept in PyCSp contrary to JvCSP

        # .add("BinPacking", data="BinPacking_n1c1w4a.json", variant="mdd", special=True)
        )

same = (Tester(NAME)
        .add("Auction", data="Auction_example.json")
        .add("Auction", data="Auction_example.txt", prs_py="Auction_Parser", prs_jv="Auction_Parser")
        .add("BinPacking", data="BinPacking_n1c1w4a.json")
        .add("BinPacking", data="BinPacking_n1c1w4a.json", variant="table")
        .add("BinPacking", data="BinPacking_example.txt", prs_py="BinPacking_Parser", prs_jv="BinPacking_Parser")
        .add("Blackhole", data="Blackhole.json")
        .add("Bugs", data="Bugs_example.json")
        .add("Bugs", data="Bugs_example.txt", prs_py="Bugs_Parser", prs_jv="Bugs_Parser")
        .add("BusScheduling", data="BusScheduling_c1a.json")
        .add("BusScheduling", data="BusScheduling_r1.json")
        .add("BusScheduling", data="BusScheduling_t1.json")
        .add("Coloring", data="Coloring_rand1.json")
        .add("Coloring", data="Coloring_rand1.json", variant="csp")
        .add("Cutstock", data="Cutstock_small.json")
        .add("Fastfood", data="Fastfood_ff01.json")
        .add("Fastfood", data="Fastfood_example.dzn", prs_py="Fastfood_ParserZ", prs_jv="Fastfood_ParserZ")

        .add("Futoshiki", data="Futoshiki_futo3_0.json")
        .add("GraphColoring", data="GraphColoring_1-fullins-3.json")
        .add("GraphColoring", data="GraphColoring_1-fullins-3.json", variant="sum")
        .add("GraphColoring", data="GraphColoring_qwhdec-o18-h120-1.json")
        .add("GraphColoring", data="GraphColoring_qwhdec-o18-h120-1.json", variant="sum")
        .add("GraphMaxAcyclic", data="GraphMaxAcyclic_example.txt", prs_py="GraphMaxAcyclic_Parser", prs_jv="GraphMaxAcyclic_Parser")
        .add("GraphMaxAcyclic", data="GraphMaxAcyclic_example.txt", prs_py="GraphMaxAcyclic_Parser", prs_jv="GraphMaxAcyclic_Parser", variant="cnt")
        .add("HCPizza", data="HCPizza_tiny.txt", prs_py="HCPizza_Parser", prs_jv="HCPizza_Parser")
        .add("HCPizza", data="HCPizza_small.txt", prs_py="HCPizza_Parser", prs_jv="HCPizza_Parser")
        .add("Kakuro", data="Kakuro_easy-000.json")
        .add("Kakuro", data="Kakuro_easy-000.json", variant="table")
        .add("Knapsack", data="Knapsack_20-50-00.json")
        .add("LatinSquare", data="LatinSquare_qwh-o030-h320.json")
        .add("LatinSquareB", data="LatinSquareB_7-2-0.json")
        .add("LinearArrangement", data="LinearArrangement_04.json")
        .add("MagicSquare", data="MagicSquare_example0.txt", prs_py="MagicSquare_Parser", prs_jv="MagicSquare_Parser")
        .add("MagicSquare", data="MagicSquare_example1.txt", prs_py="MagicSquare_Parser", prs_jv="MagicSquare_Parser")
        .add("Mario", data="Mario_easy-2.json", variant="table")
        .add("MarketSplit", data="MarketSplit_04.json")
        .add("MultiKnapsack", data="MultiKnapsack_example.txt", prs_py="MultiKnapsack_Parser", prs_jv="MultiKnapsack_Parser")
        .add("Nonogram", data="Nonogram_example.txt", prs_py="Nonogram_Parser", prs_jv="Nonogram_Parser")
        .add("Nonogram", data="Nonogram_example.txt", prs_py="Nonogram_Parser", prs_jv="Nonogram_Parser", variant="table")
        .add("OpenStacks", data="OpenStacks_example.dzn", prs_py="OpenStacks_ParserZ", prs_jv="OpenStacks_ParserZ", variant="m1")
        .add("OpenStacks", data="OpenStacks_example.dzn", prs_py="OpenStacks_ParserZ", prs_jv="OpenStacks_ParserZ", variant="m2")
        .add("PrizeCollecting", data="PrizeCollecting_example.dzn", prs_py="PrizeCollecting_ParserZ", prs_jv="PrizeCollecting_ParserZ", special=True)
        .add("PseudoBoolean", data="PseudoBoolean_example.opb", prs_py="PseudoBoolean_Parser", prs_jv="PseudoBoolean_Parser")
        .add("RectPacking", data="RectPacking_perfect-001.json", special=True)
        .add("RoomMate", data="RoomMate_sr0006.json")
        .add("Sat", data="Sat_flat30-16.json", variant="sum")
        .add("Sat", data="Sat_flat30-16.json", variant="dual")
        .add("Sat", data="Sat_flat30-16.json", variant="clause")
        .add("Shikaku", data="Shikaku_grid1.json")
        .add("Sonet", data="Sonet_sonet1.json")
        .add("Sonet", data="Sonet_sonet3-4.json")
        .add("StripPacking", data="StripPacking_C1P1.json")
        .add("Subisomorphism", data="Subisomorphism_A-01.json")
        .add("Sudoku", data="Sudoku_s13a.json")
        .add("Sudoku", data="Sudoku_s13a.json", variant="table")
        .add("Sudoku", data="Sudoku_example.txt", prs_py="Sudoku_Parser", prs_jv="Sudoku_Parser")
        .add("TravelingSalesman", data="TravelingSalesman_10-20-0.json")
        .add("VesselLoading", data="VesselLoading-inst1.json")
        )

xcsp = (Tester(NAME)
        .add(same.instances)
        )

inprogress = (Tester(NAME)
              .add(same.instances)
              .add("Fastfood2", data="Fastfood_ff01.json")
              .add("Mario", data="Mario_easy-2.json")
              )

run(diff, same, xcsp)

==> pycsp3-1.0.7.tar.gz: pycsp3-1.0.7/pycsp3/problems/tests/g3_pattern.py <==
from pycsp3.problems.tests.tester import Tester, run

NAME = "g3_pattern"

diff = (Tester(NAME)
        .add("Dominoes", data="Dominoes_grid1.json")  # ok, unary constraints managed differently
        .add("Lightup", data="Lightup_example.txt", prs_py="Lightup_Parser", prs_jv="Lightup_Parser")  # ok, JvCSP more compact because reordering vars in count
        .add("ProgressiveParty", data="ProgressiveParty_example.txt", prs_py="ProgressiveParty_Parser", prs_jv="ProgressiveParty_Parser", special=True)
        # ok, group of alldiffExcept in PyCSp contrary to JvCSP
        # .add("BinPacking", data="BinPacking_n1c1w4a.json", variant="mdd", special=True)
        )

same = (Tester(NAME)
        .add("Auction", data="Auction_example.json")
        .add("Auction", data="Auction_example.txt", prs_py="Auction_Parser", prs_jv="Auction_Parser")
        .add("BinPacking", data="BinPacking_n1c1w4a.json")
        .add("BinPacking", data="BinPacking_n1c1w4a.json", variant="table")
        .add("BinPacking", data="BinPacking_example.txt", prs_py="BinPacking_Parser", prs_jv="BinPacking_Parser")
        .add("Blackhole", data="Blackhole.json")
        .add("Bugs", data="Bugs_example.json")
        .add("Bugs", data="Bugs_example.txt", prs_py="Bugs_Parser", prs_jv="Bugs_Parser")
        .add("BusScheduling", data="BusScheduling_c1a.json")
        .add("BusScheduling", data="BusScheduling_r1.json")
        .add("BusScheduling", data="BusScheduling_t1.json")
        .add("Coloring", data="Coloring_rand1.json")
        .add("Coloring", data="Coloring_rand1.json", variant="csp")
        .add("Cutstock", data="Cutstock_small.json")
        .add("Eternity", data="Eternity_07x05.json")
        .add("Eternity", data="Eternity_example.txt", prs_py="Eternity_Parser", prs_jv="Eternity_Parser")
        .add("Fastfood", data="Fastfood_ff01.json")
        .add("Fastfood", data="Fastfood_example.dzn", prs_py="Fastfood_ParserZ", prs_jv="Fastfood_ParserZ")
        .add("Futoshiki", data="Futoshiki_futo3_0.json")
        .add("GraphColoring", data="GraphColoring_1-fullins-3.json")
        .add("GraphColoring", data="GraphColoring_1-fullins-3.json", variant="sum")
        .add("GraphColoring", data="GraphColoring_qwhdec-o18-h120-1.json")
        .add("GraphColoring", data="GraphColoring_qwhdec-o18-h120-1.json", variant="sum")
        .add("GraphMaxAcyclic", data="GraphMaxAcyclic_example.txt", prs_py="GraphMaxAcyclic_Parser", prs_jv="GraphMaxAcyclic_Parser")
        .add("GraphMaxAcyclic", data="GraphMaxAcyclic_example.txt", prs_py="GraphMaxAcyclic_Parser", prs_jv="GraphMaxAcyclic_Parser", variant="cnt")
        .add("HCPizza", data="HCPizza_tiny.txt", prs_py="HCPizza_Parser", prs_jv="HCPizza_Parser")
        .add("HCPizza", data="HCPizza_small.txt", prs_py="HCPizza_Parser", prs_jv="HCPizza_Parser")
        .add("Kakuro", data="Kakuro_easy-000.json")
        .add("Kakuro", data="Kakuro_easy-000.json", variant="table")
        .add("Knapsack", data="Knapsack_20-50-00.json")
        .add("LatinSquare", data="LatinSquare_qwh-o030-h320.json")
        .add("LatinSquareB", data="LatinSquareB_7-2-0.json")
        .add("LinearArrangement", data="LinearArrangement_04.json")
        .add("MagicSquare", data="MagicSquare_example0.txt", prs_py="MagicSquare_Parser", prs_jv="MagicSquare_Parser")
        .add("MagicSquare", data="MagicSquare_example1.txt", prs_py="MagicSquare_Parser", prs_jv="MagicSquare_Parser")
        .add("Mario", data="Mario_easy-2.json", variant="table")
        .add("MarketSplit", data="MarketSplit_04.json")
        .add("MultiKnapsack", data="MultiKnapsack_example.txt", prs_py="MultiKnapsack_Parser", prs_jv="MultiKnapsack_Parser")
        .add("Nonogram", data="Nonogram_example.txt", prs_py="Nonogram_Parser", prs_jv="Nonogram_Parser")
        .add("Nonogram", data="Nonogram_example.txt", prs_py="Nonogram_Parser", prs_jv="Nonogram_Parser", variant="table")
        .add("OpenStacks", data="OpenStacks_example.dzn", prs_py="OpenStacks_ParserZ", prs_jv="OpenStacks_ParserZ", variant="m1")
        .add("OpenStacks", data="OpenStacks_example.dzn", prs_py="OpenStacks_ParserZ", prs_jv="OpenStacks_ParserZ", variant="m2")
        .add("PrizeCollecting", data="PrizeCollecting_example.dzn", prs_py="PrizeCollecting_ParserZ", prs_jv="PrizeCollecting_ParserZ", special=True)
        .add("PseudoBoolean", data="PseudoBoolean_example.opb", prs_py="PseudoBoolean_Parser", prs_jv="PseudoBoolean_Parser")
        .add("RectPacking", data="RectPacking_perfect-001.json", special=True)
        .add("RoomMate", data="RoomMate_sr0006.json")
        .add("Sat", data="Sat_flat30-16.json", variant="sum")
        .add("Sat", data="Sat_flat30-16.json", variant="dual")
        .add("Sat", data="Sat_flat30-16.json", variant="clause")
        .add("Shikaku", data="Shikaku_grid1.json")
        .add("Sonet", data="Sonet_sonet1.json")
        .add("Sonet", data="Sonet_sonet3-4.json")
        .add("StripPacking", data="StripPacking_C1P1.json")
        .add("Subisomorphism", data="Subisomorphism_A-01.json")
        .add("Sudoku", data="Sudoku_s13a.json")
        .add("Sudoku", data="Sudoku_s13a.json", variant="table")
        .add("Sudoku", data="Sudoku_example.txt", prs_py="Sudoku_Parser", prs_jv="Sudoku_Parser")
        .add("TravelingSalesman", data="TravelingSalesman_10-20-0.json")
        .add("VesselLoading", data="VesselLoading-inst1.json")
        )

xcsp = (Tester(NAME)
        .add(same.instances)
        )

inprogress = (Tester(NAME)
              .add(same.instances)
              .add("Fastfood2", data="Fastfood_ff01.json")
              .add("Mario", data="Mario_easy-2.json")
              )

run(diff, same, xcsp)
